cmoncrawl.aggregator.utils.athena\_query\_maker
===============================================

.. automodule:: cmoncrawl.aggregator.utils.athena_query_maker

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      crawl_query
      crawl_url_to_name
      date_to_sql_format
      get_name
      prepare_athena_sql_query
      prepare_athena_where_conditions
      url_query_based_on_match_type
      url_query_date_range
   
   

   
   
   

   
   
   



